=================
cl-sii Python lib
=================

Python library for Servicio de Impuestos Internos (SII) of Chile.

Status
-------------

.. image:: https://circleci.com/gh/fyndata/lib-cl-sii-python/tree/develop.svg?style=shield
    :target: https://circleci.com/gh/fyndata/lib-cl-sii-python/tree/develop
    :alt: CI status


Supported Python versions
-------------------------

Only Python 3.7. Python 3.6 and below will not work because we use some features introduced in
Python 3.7.
